SimplePageDecorator

Struct SimplePageDecorator 

pub struct SimplePageDecorator {
    pub(crate) page: usize,
    pub(crate) margins: Option<Margins>,
    pub(crate) header_cb: Option<Box<dyn Fn(usize) -> Box<dyn Element>>>,
}
Prepares a page of a document with margins and a header.

Per default, this decorator does not modify the page. If margins have been set with the set_margins method, they are applied to every page. If a header callback is configured with the set_header method, it will be called for every page and its return value will be rendered at the beginning of the page (after the margins have been applied).

Fields

page: usizemargins: Option<Margins>header_cb: Option<Box<dyn Fn(usize) -> Box<dyn Element>>>

Implementations

Source

impl SimplePageDecorator

pub fn new() -> SimplePageDecorator

Creates a new page decorator that does not modify the page.

pub fn clone_for_document(&self) -> SimplePageDecorator

Returns a clone of this decorator suitable for attaching to another Document.

Note: the header callback is not cloned (it is set to None on the clone) because boxed closures are not universally cloneable. This preserves the margins and resets the page counter to 0 for the cloned instance.

pub fn set_margins(&mut self, margins: impl Into<Margins>)

Sets the margins for all pages of this document.

If this method is not called, the full page is used.

pub fn set_header<F, E>(&mut self, cb: F)
where F: Fn(usize) -> E + 'static, E: Element + 'static,

Sets the header generator for this document.

The given closure will be called once per page. Its argument is the page number (starting with 1), and its return value will be rendered at the top of the page. The document content will start directly after the element.

pub fn margins(&self) -> Option<Margins>

Return the margins currently configured for this decorator (useful for testing).