PageDecoratorClone

Trait PageDecoratorClone 

pub trait PageDecoratorClone {
    // Required method
    fn clone_box(&self) -> Box<dyn PageDecorator>;
}
A helper trait to make PageDecorator objects cloneable as trait objects.

This is implemented automatically for any T that implements PageDecorator + Clone. It provides a clone_box method used to clone boxed decorators.

Required Methods

fn clone_box(&self) -> Box<dyn PageDecorator>

Clone the boxed decorator into a new boxed trait object.

Implementors

Source

impl<T> PageDecoratorClone for T
where T: PageDecorator + Clone + 'static,