pub trait ElementClone {
// Required method
fn clone_box(&self) -> Box<dyn Element>;
}Expand description
A helper trait to make Element objects cloneable as trait objects.
Types that implement Element and Clone will automatically get an implementation of
ElementClone which allows cloning boxed elements via clone_box.