pub trait PageDecoratorClone {
// Required method
fn clone_box(&self) -> Box<dyn PageDecorator>;
}Expand description
A helper trait to make PageDecorator objects cloneable as trait objects.
This is implemented automatically for any T that implements PageDecorator + Clone.
It provides a clone_box method used to clone boxed decorators.
Required Methods
Sourcefn clone_box(&self) -> Box<dyn PageDecorator>
fn clone_box(&self) -> Box<dyn PageDecorator>
Clone the boxed decorator into a new boxed trait object.